==> cxxtools_2.0.orig.tar.gz: cxxtools-2.0/src/settings.cpp <==
/*
 * Copyright (C) 2005-2007 by Dr. Marc Boris Duerner
 * Copyright (C) 2005 Stephan Beal
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "cxxtools/settings.h"
#include "settingsreader.h"
#include "settingswriter.h"

namespace cxxtools {

SettingsError::SettingsError(const char* what, unsigned line)
: SerializationError(what)
, _line(line)
{}


Settings::Settings()
{}


void Settings::load(std::basic_istream<cxxtools::Char>& is)
{
    SettingsReader reader(is);
    reader.parse(*this);
}


void Settings::save(std::basic_ostream<cxxtools::Char>& os ) const
{
    SettingsWriter writer(os);
    writer.write(*this);
}

}

==> cxxtools_3.0.0.orig.tar.gz: cxxtools-3.0/src/settings.cpp <==
/*
 * Copyright (C) 2005-2007 by Dr. Marc Boris Duerner
 * Copyright (C) 2005 Stephan Beal
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "cxxtools/settings.h"
#include "settingsreader.h"
#include "settingswriter.h"

namespace cxxtools {

SettingsError::SettingsError(const std::string& what, unsigned line)
: SerializationError(what)
, _line(line)
{}


Settings::Settings()
{}


void Settings::load(std::basic_istream<cxxtools::Char>& is)
{
    SettingsReader reader(is);
    reader.parse(*this);
}


void Settings::save(std::basic_ostream<cxxtools::Char>& os ) const
{
    SettingsWriter writer(os);
    writer.write(*this);
}

}
